﻿/**
 * WCFを使用したサンプルプログラム12: リポジトリのディレクトリを削除するサンプルプログラムです。
 * 
 * [本サンプルの実行手順]
 * 
 * <pre>
 * 1. Visual Studio 2008以上で新規プロジェクトを作成する (以下は2008での表示名)
 * 1.1 プロジェクト名は「BizStreamWebApplication」
 * 1.2 「プロジェクトの種類」は「Visual C# / Web」
 * 1.3 「テンプレート」は「ASP.NET Webアプリケーション」
 * 2. 「ソリューションエクスプローラ」にて右クリック後、「サービス参照の追加..」をクリックする
 * 2.1 「アドレス」には「http://wsssrv:8080/axis2/services/bizstream?wsdl」を入力し「移動」をクリックする
 * 2.2 認証を要求されるので、ユーザ名を「bizuser1」、パスワードを「bizuser1」と入力し「OK」をクリックする
 * 2.3 「名前空間」には「BizStreamServiceReference」を入力し「OK」をクリックする
 * 3. 「ソリューションエクスプローラ」にて右クリック後、「サービス参照の追加..」をクリックする
 * 3.1 「アドレス」には「http://wsssrv:8080/axis2/services/cms?wsdl」を入力し「移動」をクリックする
 * 3.2 認証を要求されるので、ユーザ名を「bizuser1」、パスワードを「bizuser1」と入力し「OK」をクリックする
 * 3.3 「名前空間」には「CmsServiceReference」を入力し「OK」をクリックする
 * 4. 本サンプルを上記プロジェクトに上書きし、ビルド後、実行する
 * </pre>
 * 
 * @author Copyright 2001-2018 BrainSellers.com Corp. All Rights Reserved.
 * @version 1.0.1
 * @since 4.9.0
 */

using System;
using System.ServiceModel;
using System.ServiceModel.Channels;
using System.Web;
using BizStreamWebApplication.CmsServiceReference;

namespace BizStreamWebApplication
{
    public partial class WSS_WCF_Sample12 : System.Web.UI.Page
    {
        // Webサービスサーバのホスト名
        const string WSS_HOST_NAME = "wsssrv";

        // Webサービスのエンドポイントプリフィックス
        const string WSS_SERVICE_LOCATION = "http://" + WSS_HOST_NAME + ":8080/axis2/services";

        // BASIC認証のユーザ名
        const string USER_NAME = "bizuser1";

        // BASIC認証のパスワード
        const string PASSWORD = "bizuser1";

        // 監査ロギング用のユーザ定義
        const string USER_DEF = "AAA";

        // 削除するフォルダパス
        const string TARGET_FOLDER_PATH = "/Sample11_WCF";


        protected void Page_Load(object sender, EventArgs e)
        {
            // リポジトリ内のディレクトリを削除
            removeDir();

            // ブラウザに結果を表示
            Response.Clear();
            Response.ContentType = "text/html;charset=UTF-8";
            Response.Write("<HTML><HEAD><TITLE>WSS_WCF_Sample12</TITLE></HEAD><BODY>");
            Response.Write("正常終了しました。<BR>");
            Response.Write("リポジトリから削除されたディレクトリ: " + TARGET_FOLDER_PATH);
            Response.Write("</BODY></HTML>");
            Response.Flush();
            HttpContext.Current.ApplicationInstance.CompleteRequest();
        }

        private success removeDir()
        {
            // クライアントを生成
            cmsPortTypeClient client =
                new cmsPortTypeClient("CmsSOAP11port",
                    WSS_SERVICE_LOCATION + "/cms?UserDef=" + USER_DEF);

            // 認証の設定
            BindingElementCollection elements = client.Endpoint.Binding.CreateBindingElements();
            elements.Find<HttpTransportBindingElement>().AuthenticationScheme =
                System.Net.AuthenticationSchemes.Basic;
            client.ClientCredentials.UserName.UserName = USER_NAME;
            client.ClientCredentials.UserName.Password = PASSWORD;

            // MTOMを有効化
            elements.Remove<TextMessageEncodingBindingElement>();
            MtomMessageEncodingBindingElement mtom = new MtomMessageEncodingBindingElement();
            mtom.ReaderQuotas.MaxStringContentLength = 100000;
            elements.Insert(0, mtom);
            elements.Find<HttpTransportBindingElement>().KeepAliveEnabled = false;
            client.Endpoint.Binding = new CustomBinding(elements);

            // リクエストメッセージの作成
            deleteRequest request = new deleteRequest();
            request.Value = TARGET_FOLDER_PATH;

            // リクエストを送信
            return client.delete(request);
        }
    }
}
